/* -*- mode: c; c-basic-offset: 4; -*- */
/* vi:set cindent ts=8 sts=4 sw=4: */
#ifndef LIB_H
#define LIB_H

#include <ncurses.h>
#include <stdlib.h>
#include <string.h>
#include <sys/types.h>

/* To avoid free()ing dangling pointers later */
#define safe_free(p) if (p) free(p),p = NULL
#define strfcpy(dst,src,n) strncpy(dst,src,n-1), *(dst + (n) - 1) = '\0'

#define whitespace(c) (((c) == ' ') || ((c) == '\t'))
#define ISSLASH(ch) (ch == '/')

#define IS_ROOT_PATH(path)      (*path == '/' && *(path+1) == '\0')

#define LONG_STRING     1024
#define STRING          256
#define SHORT_STRING    128

#define STRIP_TRAILING_SLASHES_IF_NOT_ROOT_DIR(s) \
{ \
    char *cp; \
    cp = s + strlen(s) - 1; \
    while (cp > s && *cp == '/') \
	cp--; \
    *(cp + 1) = '\0'; \
}

#undef TRUE
#define TRUE 1
#undef FALSE
#define FALSE 0
#define YES 1
#define NO 0

#undef CTRL
#define CTRL(ch) ((ch) & 0x1f)
#undef UNCTRL
#define UNCTRL(ch) (iscntrl(ch) ? ch + 'a' - 1 : ch)
#undef ESC
#define ESC CTRL('[')

/* Used by the sorting functions. */
#define LT(s1, s2) is_boolean_option_true(OPT_IGNORE_CASE) ? \
                   (strcasecmp(s1, s2) < 0) : (strcmp(s1, s2) < 0)
#define GT(s1, s2) is_boolean_option_true(OPT_IGNORE_CASE) ? \
                   (strcasecmp(s1, s2) > 0) : (strcmp(s1, s2) > 0)

void clear_accumulator(void);
void add_to_accumulator(int value);
int accumulator_value(void);
void error_exit(char *fmt,...);
void *safe_calloc(size_t nmemb, size_t size);
void *safe_malloc(size_t size);
void safe_realloc(void **p, size_t size);
char *strstr_icase(char *haystack, char *needle);
char *safe_strdup(const char *s);
char *strclean(char *str);
char *expand_path(char *s, size_t slen);
char *rm_leading_and_trailing_ws(char *string);

#endif				/* LIB_H */
